# 026

|                                                       | 026-1b0610z0049j          |
|:------------------------------------------------------|:--------------------------|
| bindTime                                              | 1710171538374             |
| createTime                                            | 0                         |
| deviceFeatureCode                                     | 1b0610z0049j              |
| deviceFeatureName                                     | BCD-610WP1BWF1S3/HC4(HAB) |
| deviceId                                              | <redacted>                |
| deviceNickName                                        | Hisense refrigerator      |
| deviceTypeCode                                        | 026                       |
| deviceTypeName                                        |                           |
| offlineState                                          | 1                         |
| puid                                                  | <redacted>                |
| role                                                  | 1                         |
| roomId                                                | 3836987                   |
| roomName                                              | default_room              |
| seq                                                   | 0                         |
| statusList.AIR_FRESHNESS                              | 0                         |
| statusList.ODOR_SENSOR_FAULT_FLAG                     | 0                         |
| statusList.ODOR_SENSOR_NO_DISTURB_MODE_STATUS         | 1                         |
| statusList.ODOR_SENSOR_SENSITIVITY                    | 3                         |
| statusList.ODOR_SENSOR_SWITHC_STATUS                  | 1                         |
| statusList.STERI_PURI_CYCLE_FLAG                      | 1                         |
| statusList.ai_energy_mode_switch                      | 0                         |
| statusList.alarm_key                                  | 0                         |
| statusList.alarm_sound_volume                         | 0                         |
| statusList.ali_wifi_fault_flag                        | 0                         |
| statusList.automatic_ice_making                       | 1                         |
| statusList.camera_state                               | 0                         |
| statusList.charcoal_filter_expiration_alarm           | 0                         |
| statusList.charcoal_filter_surplus_time               | 0                         |
| statusList.charcoal_filter_time_reset                 | 0                         |
| statusList.child_lock_open_alarm                      | 0                         |
| statusList.child_lock_open_door_sound_alarm           | 0                         |
| statusList.child_lock_switch_exist                    | 0                         |
| statusList.child_lock_switch_status                   | 0                         |
| statusList.commodity_inspection                       | 0                         |
| statusList.compressor_condition                       | 0                         |
| statusList.compressor_frequency                       | 0                         |
| statusList.condensation_fan_failure_status            | 0                         |
| statusList.control_failure_status                     | 0                         |
| statusList.custard_room                               | 36                        |
| statusList.daily_energy_kwh                           | 0                         |
| statusList.date_display_format_status                 | 0                         |
| statusList.date_format_status                         | 0                         |
| statusList.date_time_format_day_state                 | 0                         |
| statusList.date_time_format_month_state               | 0                         |
| statusList.date_time_format_year_state                | 0                         |
| statusList.dbd_clean_mode                             | 0                         |
| statusList.debacilli_mode                             | 0                         |
| statusList.display_panel_ronshen                      | 1                         |
| statusList.displayboard_brand                         | 3                         |
| statusList.displayboard_key_setting                   | 0                         |
| statusList.displayboard_type                          | 75                        |
| statusList.displayboard_version                       | 1                         |
| statusList.door_close_light_status                    | 0                         |
| statusList.door_close_ui_display_status               | 0                         |
| statusList.door_num_four_color                        | 0                         |
| statusList.door_num_one_color                         | 0                         |
| statusList.door_num_three_color                       | 0                         |
| statusList.door_num_two_color                         | 0                         |
| statusList.door_open_light_status                     | 0                         |
| statusList.door_open_ui_display_status                | 0                         |
| statusList.electric_current                           | 111                       |
| statusList.electric_energy_one_tenths_value           | 0                         |
| statusList.electric_energy_percentile_thousands_value | 5                         |
| statusList.envi_temp_sens_head_failure                | 0                         |
| statusList.environment_humidity                       | 55                        |
| statusList.environment_real_temperature               | 30                        |
| statusList.existing_fuzzy_mode                        | 0                         |
| statusList.existing_holiday_mode                      | 0                         |
| statusList.existing_lock_fresh_mode                   | 0                         |
| statusList.existing_save_mode                         | 1                         |
| statusList.existing_sf_mode                           | 1                         |
| statusList.existing_sr_mode                           | 1                         |
| statusList.fast_store_mode_exist                      | 0                         |
| statusList.fast_store_mode_status                     | 0                         |
| statusList.filter_alarm_time                          | 0                         |
| statusList.filter_state                               | 45                        |
| statusList.free_defrosting_failure                    | 0                         |
| statusList.free_evap_temp_sens_head_failure           | 0                         |
| statusList.free_fan_failure                           | 0                         |
| statusList.free_key                                   | 0                         |
| statusList.free_room                                  | 1                         |
| statusList.free_room_open                             | 0                         |
| statusList.free_room_open_2                           | 0                         |
| statusList.free_room_over_temp_alarm_failure          | 0                         |
| statusList.free_temp_sens_head_failure                | 0                         |
| statusList.freeze_door_open_time                      | 0                         |
| statusList.freeze_max_temperature                     | -13                       |
| statusList.freeze_min_temperature                     | -24                       |
| statusList.freeze_poweroff_ad                         | 0                         |
| statusList.freeze_poweron_ad                          | 0                         |
| statusList.freeze_real_temperature                    | -20                       |
| statusList.freeze_sensor_real_temperature             | -40                       |
| statusList.freeze_temperature                         | -18                       |
| statusList.frost_state                                | 0                         |
| statusList.froze_convert_to_refri_switch_status       | 0                         |
| statusList.fruit_vegetables_temperature               | 0                         |
| statusList.fuzzy_mode                                 | 0                         |
| statusList.gold_water_supply_mode                     | 0                         |
| statusList.high_humidity                              | 0                         |
| statusList.high_temperature                           | 0                         |
| statusList.holiday_mode                               | 0                         |
| statusList.human_on_off_status                        | 0                         |
| statusList.human_sense_light_status                   | 0                         |
| statusList.human_sense_ui_display_state               | 0                         |
| statusList.human_sensor_switch_exist                  | 0                         |
| statusList.humdy_test_switch_state                    | 0                         |
| statusList.humidity sensor_failure                    | 0                         |
| statusList.ice_making_b_switch_status                 | 0                         |
| statusList.ice_making_full_status                     | 0                         |
| statusList.ice_making_machine_failure                 | 0                         |
| statusList.ice_making_state                           | 1                         |
| statusList.ice_sensor_failure_flag                    | 0                         |
| statusList.ice_temperature_sensor_header_failure_flag | 0                         |
| statusList.inlet pipe_temp_sens_head_failure          | 0                         |
| statusList.key_press_sound_volume                     | 0                         |
| statusList.language_select                            | 0                         |
| statusList.load_operation_status2                     | 0                         |
| statusList.lock_fresh_mode                            | 0                         |
| statusList.lock_key                                   | 0                         |
| statusList.low_humidity                               | 0                         |
| statusList.low_temperature                            | 0                         |
| statusList.low_wine_area_c_evaporator_fault           | 0                         |
| statusList.low_wine_area_c_fan_fault                  | 0                         |
| statusList.low_wine_area_c_humdy_fault                | 0                         |
| statusList.low_wine_area_c_temp_fault                 | 0                         |
| statusList.lumin_value_of_interior_light              | 0                         |
| statusList.mainboard_type                             | 70                        |
| statusList.mainboard_version                          | 151                       |
| statusList.market_mode_exist                          | 0                         |
| statusList.measured_vibrations                        | 0                         |
| statusList.medium_humidity                            | 0                         |
| statusList.medium_temperature                         | 0                         |
| statusList.micro_water_supply_mode                    | 0                         |
| statusList.mid_wine_area_b_evaporator_fault           | 0                         |
| statusList.mid_wine_area_b_fan_fault                  | 0                         |
| statusList.mid_wine_area_b_humdy_fault                | 0                         |
| statusList.mid_wine_area_b_temp_fault                 | 0                         |
| statusList.mode_key                                   | 0                         |
| statusList.model_type                                 | 26                        |
| statusList.monitor                                    | 0                         |
| statusList.monitor_set                                | 0                         |
| statusList.monitor_set_act                            | 0                         |
| statusList.night_mode_end_hour                        | 0                         |
| statusList.night_mode_end_min                         | 0                         |
| statusList.night_mode_light_dark_level                | 0                         |
| statusList.night_mode_screen_dark_level               | 0                         |
| statusList.night_mode_start_hour                      | 0                         |
| statusList.night_mode_start_min                       | 0                         |
| statusList.night_mode_status                          | 0                         |
| statusList.normal_sound_size                          | 0                         |
| statusList.not_active                                 | 1                         |
| statusList.open_freeze_door_alarm                     | 0                         |
| statusList.open_refrigerator_door_alarm               | 0                         |
| statusList.open_the_door_alarm                        | 0                         |
| statusList.open_variation_door_alarm                  | 0                         |
| statusList.pairing                                    | 0                         |
| statusList.pairing_active                             | 0                         |
| statusList.power_hundred_ten_value                    | 0                         |
| statusList.power_one_tenths_value                     | 0                         |
| statusList.power_voltage                              | 0                         |
| statusList.quiet_mode_status                          | 0                         |
| statusList.real_humidity                              | 0                         |
| statusList.real_humidity_b                            | 0                         |
| statusList.real_humidity_c                            | 0                         |
| statusList.ref_light                                  | 0                         |
| statusList.refr_defrosting_failure                    | 0                         |
| statusList.refr_dry_wet_room_sens_failure             | 0                         |
| statusList.refr_evap_temp_sens_head_failure           | 0                         |
| statusList.refr_fan_failure                           | 0                         |
| statusList.refr_key                                   | 0                         |
| statusList.refr_room                                  | 1                         |
| statusList.refr_room_open                             | 0                         |
| statusList.refr_room_over_temp_alarm                  | 0                         |
| statusList.refr_temp_sens_head_failure                | 0                         |
| statusList.refr_var_room_sens_failure                 | 0                         |
| statusList.refrigerator_door_open_time                | 0                         |
| statusList.refrigerator_freeze_swith                  | 0                         |
| statusList.refrigerator_freeze_swith_state            | 0                         |
| statusList.refrigerator_max_temperature               | 9                         |
| statusList.refrigerator_min_temperature               | 2                         |
| statusList.refrigerator_poweroff_ad                   | 0                         |
| statusList.refrigerator_poweron_ad                    | 0                         |
| statusList.refrigerator_real_temperature              | 4                         |
| statusList.refrigerator_sensor_real_temperature       | -24                       |
| statusList.refrigerator_temperature                   | 4                         |
| statusList.reserve45                                  | 0                         |
| statusList.reserve46                                  | 0                         |
| statusList.reserve47                                  | 0                         |
| statusList.reserve48                                  | 0                         |
| statusList.reserve49                                  | 0                         |
| statusList.reserve50                                  | 0                         |
| statusList.reserve51                                  | 0                         |
| statusList.reserve52                                  | 0                         |
| statusList.reserve53                                  | 0                         |
| statusList.reserve54                                  | 0                         |
| statusList.reserve55                                  | 0                         |
| statusList.reserve56                                  | 0                         |
| statusList.reserve57                                  | 0                         |
| statusList.reserve58                                  | 0                         |
| statusList.reserve59                                  | 0                         |
| statusList.reserve60                                  | 0                         |
| statusList.reserve61                                  | 65535                     |
| statusList.reserve62                                  | 65535                     |
| statusList.reserve63                                  | 65535                     |
| statusList.reserve64                                  | 65535                     |
| statusList.reserve65                                  | 65535                     |
| statusList.reserve66                                  | 65535                     |
| statusList.reserve67                                  | 65535                     |
| statusList.reserve68                                  | 65535                     |
| statusList.reserve69                                  | 65535                     |
| statusList.reserve70                                  | 65535                     |
| statusList.reserve71                                  | 65535                     |
| statusList.reserve72                                  | 65535                     |
| statusList.rgb_atmosphere_mode_b_value                | 0                         |
| statusList.rgb_atmosphere_mode_g_value                | 0                         |
| statusList.rgb_atmosphere_mode_r_value                | 0                         |
| statusList.rgb_function_mode_b_value                  | 0                         |
| statusList.rgb_function_mode_g_value                  | 0                         |
| statusList.rgb_function_mode_r_value                  | 0                         |
| statusList.rgb_light_atmosphere_brightness            | 0                         |
| statusList.rgb_light_atmosphere_on_time               | 0                         |
| statusList.rgb_light_function_brightness              | 0                         |
| statusList.rgb_light_function_on_time                 | 0                         |
| statusList.rgb_light_normal_brightness                | 0                         |
| statusList.rgb_light_normal_on_time                   | 0                         |
| statusList.rgb_light_state                            | 0                         |
| statusList.rgb_normal_mode_b_value                    | 0                         |
| statusList.rgb_normal_mode_g_value                    | 0                         |
| statusList.rgb_normal_mode_r_value                    | 0                         |
| statusList.right_free_sensor_failure                  | 0                         |
| statusList.run_status_flag_5                          | 0                         |
| statusList.running_status                             | 0                         |
| statusList.running_status3                            | 0                         |
| statusList.rx_failure                                 | 0                         |
| statusList.sabbath_mode_status                        | 0                         |
| statusList.sabbath_mode_switch_status                 | 0                         |
| statusList.save_mode                                  | 0                         |
| statusList.screen_display_brightness                  | 0                         |
| statusList.screen_display_lock                        | 0                         |
| statusList.screen_to_clock_time                       | 0                         |
| statusList.screen_to_standby_time                     | 0                         |
| statusList.sensor_failure_status                      | 0                         |
| statusList.sensor_failure_status2                     | 0                         |
| statusList.sf_mode                                    | 0                         |
| statusList.sf_sr_mutex_mode                           | 1                         |
| statusList.shelf_light_a_state                        | 0                         |
| statusList.shelf_light_atmosphere_brightness          | 0                         |
| statusList.shelf_light_atmosphere_mode_brightness     | 0                         |
| statusList.shelf_light_b_state                        | 0                         |
| statusList.shelf_light_c_state                        | 0                         |
| statusList.shelf_light_function_mode_brightness       | 0                         |
| statusList.shelf_light_function_on_time               | 0                         |
| statusList.shelf_light_normal_on_time                 | 0                         |
| statusList.show_mode                                  | 0                         |
| statusList.special_space                              | 0                         |
| statusList.sr_mode                                    | 0                         |
| statusList.standby_mode_state                         | 0                         |
| statusList.standby_mode_valid                         | 0                         |
| statusList.super_water_supply_mode                    | 0                         |
| statusList.temp_auto_ctrl_mode_exist                  | 0                         |
| statusList.temp_auto_ctrl_mode_state                  | 0                         |
| statusList.temperature_room_judge                     | 19                        |
| statusList.temperature_unit                           | 0                         |
| statusList.theme_color                                | 0                         |
| statusList.tx_failure                                 | 0                         |
| statusList.unfreeze_run_status                        | 0                         |
| statusList.unfreeze_switch_status                     | 0                         |
| statusList.unpair_all_users                           | 0                         |
| statusList.up_wine_area_a_evaporator_fault            | 0                         |
| statusList.up_wine_area_a_fan_fault                   | 0                         |
| statusList.up_wine_area_a_humdy_fault                 | 0                         |
| statusList.up_wine_area_a_temp_fault                  | 0                         |
| statusList.user_debacilli_mode                        | 0                         |
| statusList.vacuum_on_off_status                       | 0                         |
| statusList.var_room_open_2                            | 0                         |
| statusList.var_room_over_temp_alarm                   | 0                         |
| statusList.vari_evap_temp_sens_head_failure           | 0                         |
| statusList.vari_key                                   | 0                         |
| statusList.vari_room                                  | 0                         |
| statusList.vari_room_open                             | 0                         |
| statusList.vari_temp_sens_head_failure                | 0                         |
| statusList.variable_fan_failure_status                | 0                         |
| statusList.variable_heater_failure_status             | 0                         |
| statusList.variable_temperature_space                 | 0                         |
| statusList.variation_door_open_time                   | 0                         |
| statusList.variation_max_temperature                  | 5                         |
| statusList.variation_min_temperature                  | -20                       |
| statusList.variation_poweroff_ad                      | 0                         |
| statusList.variation_poweron_ad                       | 0                         |
| statusList.variation_real_temperature                 | -40                       |
| statusList.variation_sensor_real_temperature          | -40                       |
| statusList.variation_temperature                      | -40                       |
| statusList.vibration_alarm                            | 0                         |
| statusList.vibration_sensor_fault                     | 0                         |
| statusList.water_box_alarm_switch_state               | 0                         |
| statusList.water_box_lack_status                      | 0                         |
| statusList.water_box_mode_status                      | 0                         |
| statusList.water_filter_surplus_time                  | 0                         |
| statusList.water_filter_time_reset                    | 0                         |
| statusList.water_tank_install_state                   | 0                         |
| statusList.wet_and_dry_space                          | 0                         |
| statusList.wifi_fault_flag                            | 0                         |
| statusList.wifi_handshake_fault_flag                  | 0                         |
| statusList.wifi_next_sendtime                         | 0                         |
| statusList.wifi_rx_fault_flag                         | 0                         |
| statusList.wifi_setting                               | 0                         |
| statusList.wifi_tx_fault_flag                         | 0                         |
| statusList.will_fresh_light_status                    | 0                         |
| statusList.will_fress_light_exist                     | 0                         |
| statusList.will_light_market_mode_state               | 0                         |
| statusList.will_light_mode_exist                      | 0                         |
| statusList.will_light_mode_state                      | 0                         |
| statusList.will_light_switch_state                    | 0                         |
| statusList.wine_area_switch_status                    | 0                         |
| statusList.wine_b_switch__area                        | 0                         |
| statusList.wine_light                                 | 0                         |
| statusList.wine_sensor_failure_flag                   | 0                         |
| statusList.work_mode1                                 | 0                         |
| statusList.work_mode2                                 | 0                         |
| useTime                                               | 1710171538353             |
| wifiId                                                | <redacted>                |

## Generated from

- [`026`](026-1b0610z0049j.json)
